/**
  * \file main.c
  * \brief Prototype Arduino + Xbee de la tourelle
  * \author Nicolas Husse
  * \version 0.1
  * \date 05 novembre 2013
  */

#include "main.h"
#include <util/delay.h>

int inc = 60;

/**
  * \fn trame_extract
  * \brief Fonction qui extrait et spare les donnees contenues dans le buffer dans une Trame.
  * \param[in] buffer : Buffer de rception
  * \return Retourne les donnes sous la forme d'une Trame
  */
struct Trame trame_extract(unsigned char buffer[6])
{
	struct Trame trame;

	trame.type = (buffer[0] & 0xC0) >> 6;
	trame.id =  ((buffer[0] & 0x3F) << 5) + ((buffer[1] & 0xF8) >> 3);
	trame.cmd =  ((buffer[1]& 0x07) << 1) + ((buffer[2] & 0x80)>> 7);
	//trame.data = ((buffer[2] & 0x7F) << 24) + (buffer[3]<< 16) + (buffer[4]<< 8) + buffer[5];
	
	return trame;
}

/**
  * \fn trame_compress
  * \brief Fonction qui compresse une Trame dans un buffer afin de l'envoyer.
  * \param[in] trame : Trame contenant les donnees  mettre
  * \param[out] buffer : Buffer de sortie
  */
void trame_compress(struct Trame trame, unsigned char buffer[6])
{
	buffer[0] = ((trame.type & 0x03) << 6) + ((trame.id & 0x07E0) >> 5);
	buffer[1] = ((trame.id & 0x001F) << 3) + ((trame.cmd & 0x0E) >> 1);
	if(trame.cmd == 1)
	{
		buffer[2] = ((trame.cmd & 0x01) << 7) + ((trame.trx & 0x01) << 6) + ((trame.data & 0x01F80000) >> 19);
		buffer[3] = ((trame.data & 0x0007F800) >> 11);
		buffer[4] = ((trame.data & 0x000007F8) >> 3);
		buffer[5] = ((trame.data & 0x00000007) << 5);
	}
}

/** 
  * \fn init
  * \brief Initialisation du programme.
  **/
void init(void)
{
	serial_init();
	spi_init();
	mrf_init();
}

int main(void)
{
	init();
	sei();
	serial_send(0x62);

	while(1)
	{
		if(mrf_status == mrf_idle_state) // Si le mrf est disponible, on lit son statut.
		{
			unsigned int state = mrf_status_read();
			serial_send(0x88);
			char temp = (unsigned char) ((state & 0xFF00) >> 8);
			serial_send(0x89);
			serial_send(temp);
			temp = (unsigned char) (state & 0x00FF);
			serial_send(0x90);
			serial_send(temp);
			serial_send(0x91);
			if(inc == 0) // Tout les 60 cycles et si le mrf est disponible, on envoie un paquet.
			{
				struct mrf_package envoie;
				envoie.package[0] = 'a';
				envoie.size = 1;
				mrf_package_send(&envoie);
				inc = 60;
			}
		}
		else 
		{
			if(inc == 0) // Tout les 60 cycles et si le mrf est disponible, on envoie un paquet.
			{
				serial_send(0x87);
				serial_send(mrf_status); // Affichage du statut du mrf.
				inc = 60;
			}
		}
		inc--;
		
	}
	
	return 0;
}

/** 
  * \fn ISR
  * \brief Interruption USART
  */
ISR(USART_RX_vect)
{
	char temp = UDR0;
	if(mrf_status == mrf_idle_state) // Si le mrf est disponible, on envoie un paquet.
	{
		struct mrf_package envoie;
		envoie.package[0] = temp;
		envoie.size = 1;
		mrf_package_send(&envoie);
		serial_send(temp);
	}
	else
		serial_send(0x00);
}