/**
  * \file main.h
  * \brief Header de main.c
  * \author Nicolas Husse
  * \version 0.1
  * \date 07 novembre 2013
  */
#ifndef MAIN_H_
#define MAIN_H_

#include "config.h"
#include "serial.h"
#include "spi.h"
#include "mrf49xa.h"

/**
  * \struct Trame
  * \brief Structure regroupant les donnes d'une trame.
  */
struct Trame 
{
	unsigned char type; /*!< Type de l'emmeteur (Base, tourelle, bracelet), 2 bits */
	unsigned int id; /*!< Id de l'emetteur, 11 bits */
	unsigned char cmd; /*!< Id de la commande, 4 bits */
	unsigned char trx; /*!< Emission ou reception, 1 bit */
	unsigned long data; /*!< Donnes de la trame, 30 bits */
} trame;

/**
  * \fn trame_extract
  * \brief Fonction qui extrait et spare les donnees contenues dans le buffer dans une Trame.
  * \param[in] buffer : Buffer de rception
  * \return Retourne les donnes sous la forme d'une Trame
  */
struct Trame trame_extract(unsigned char buffer[6]);

/**
  * \fn trame_compress
  * \brief Fonction qui compresse une Trame dans un buffer afin de l'envoyer.
  * \param[in] trame : Trame contenant les donnees  mettre
  * \param[out] buffer : Buffer de sortie
  */
void trame_compress(struct Trame trame, unsigned char buffer[6]);

/** 
  * \fn init
  * \brief Initialisation du programme.
  **/
void init(void);

#endif /* MAIN_H_ */