/**
  * \file mrf49xa_registre.h
  * \brief Registre du MRF49XA
  * \author Nicolas Husse
  * \version 0.1
  * \date 02 Dcembre 2013
  */

#ifndef MRF49XA_REGISTRE_H_
#define MRF49XA_REGISTRE_H_

/** 
  * Registre & Bit
  */

#define MRF_STSREG		0x0000
#define MRF_TXRXFIFO	0x8000
#define MRF_POR			0x4000
#define MRF_TXOWRXOF	0x2000
#define MRF_WUTINT		0x1000
#define MRF_LCEXINT		0x0800
#define MRF_LBTD		0x0400
#define MRF_FIFOEM		0x0200
#define MRF_ATRSSI		0x0100
#define MRF_DQDO		0x0080
#define MRF_CLKRL		0x0040
#define MRF_AFCCT		0x0020
#define MRF_OFFSV		0x0010
#define MRF_OFFSB		0x000F

#define MRF_GENCREG		0x8000
#define	MRF_TXDEN		0x0080
#define MRF_FIFOEN		0x0040
#define MRF_FBS_915		0x0030
#define MRF_FBS_868		0x0020
#define MRF_FBS_433		0x0010
#define MRF_LCS_160		0x000F
#define MRF_LCS_155		0x000E
#define MRF_LCS_150		0x000D
#define MRF_LCS_145		0x000C
#define MRF_LCS_140		0x000B
#define MRF_LCS_135		0x000A
#define MRF_LCS_130		0x0009
#define MRF_LCS_125		0x0008
#define MRF_LCS_120		0x0007
#define MRF_LCS_115		0x0006
#define MRF_LCS_110		0x0005
#define MRF_LCS_105		0x0004
#define MRF_LCS_100		0x0003
#define MRF_LCS_095		0x0002
#define MRF_LCS_090		0x0001
#define MRF_LCS_085		0x0000

#define MRF_AFCCREG		0xC400
#define MRF_AUTOMS_INDP	0x00C0
#define MRF_AUTOMS_RECV	0x0080
#define MRF_AUTOMS_ONCE	0x0040
#define MRF_AUTOMS_OFF	0x0000
#define MRF_ARFO_0304	0x0030
#define MRF_ARFO_0708	0x0020
#define MRF_ARFO_1516	0x0010
#define MRF_ARFO_UNLIM	0x0000
#define MRF_MFCS		0x0008
#define MRF_HAM			0x0004
#define MRF_FOREN		0x0002
#define MRF_FOFEN		0x0000		

#define MRF_TXCREG		0x9800
#define MRF_MODPLY		0x0100
#define MRF_MODBW_240	0x00F0
#define MRF_MODBW_225	0x00E0
#define MRF_MODBW_210	0x00D0
#define MRF_MODBW_195	0x00C0
#define MRF_MODBW_180	0x00B0
#define MRF_MODBW_165	0x00A0
#define MRF_MODBW_150	0x0090
#define MRF_MODBW_135 	0x0080
#define MRF_MODBW_120 	0x0070
#define MRF_MODBW_105 	0x0060
#define MRF_MODBW_090 	0x0050
#define MRF_MODBW_075 	0x0040
#define MRF_MODBW_060 	0x0030
#define MRF_MODBW_045 	0x0020
#define MRF_MODBW_030 	0x0010
#define MRF_MODBW_015 	0x0000
#define MRF_OTXPWR_175	0x0007
#define MRF_OTXPWR_150	0x0006
#define MRF_OTXPWR_125	0x0005
#define MRF_OTXPWR_105	0x0004
#define MRF_OTXPWR_075	0x0003
#define MRF_OTXPWR_050	0x0002
#define MRF_OTXPWR_025	0x0001
#define MRF_OTXPWR_000	0x0000

#define MRF_TXBREG		0xB800
#define MRF_TX_MASK		0x00FF

#define MRF_CFSREG		0xA000
/** 
  * F0 = 10 x FA1 x (FA0 + FVAL/4000) MHz								
  * F0 = 10 x FA1 x FA0 + FVAL x FA1 / 400								
  * => FVAL = F0 / FA1 * 400 - 4000 x FA0 								
  * F0		|		FA0		|		FA1		|							
  * 433		|		43		|		1		|							
  * 868		|		43		|		2		|							
  * 915		|		30		|		3		|
  */
#define MRF_FVAL_433(f0)	f0 * 400 - 4000 * 43
#define MRF_FVAL_868(f0)	f0 / 2 * 400 - 4000 * 43
#define MRF_FVAL_915(f0)	f0 / 3 * 400 - 4000 * 30
#define MRF_FREQB_MASK		0x0FFF
#define MRF_FREQB_MIN		96
#define MRF_FREQB_MAX		3903

#define MRF_RXCREG		0x9000
#define MRF_FINTDIO		0x0400
#define MRF_DIORT_CONT	0x0300
#define MRF_DIORT_SLOW	0x0200
#define MRF_DIORT_MED	0x0100
#define MRF_DIORT_FAST	0x0000
#define MRF_RXBW_067	0x00C0
#define MRF_RXBW_134	0x00A0
#define MRF_RXBW_200	0x0080
#define MRF_RXBW_270	0x0060
#define MRF_RXBW_340	0x0040
#define MRF_RXBW_400	0x0020
#define MRF_RXLNA_20	0x0018
#define MRF_RXLNA_14	0x0010
#define MRF_RXLNA_06	0x0008
#define MRF_RXLNA_00	0x0000
#define MRF_DRSSIT_073	0x0005
#define MRF_DRSSIT_079	0x0004
#define MRF_DRSSIT_085	0x0003
#define MRF_DRSSIT_091	0x0002
#define MRF_DRSSIT_097	0x0001
#define MRF_DRSSIT_103	0x0000

#define MRF_BBFCREG		0xC228
#define MRF_ACRLC		0x0080
#define MRF_MCRLC		0x0040
#define MRF_FTYPE		0x0010
#define MRF_DQTI_MASK	0x0007

#define MRF_RXFIFOREG	0xB000
#define MRF_RXDB_MASK	0x00FF

#define MRF_FIFORSTREG	0xCA00
#define MRF_FFBC_MASK	0x00F0
#define MRF_SYCHLEN		0x0008
#define MRF_FFSC		0x0004
#define MRF_FSCF		0x0002
#define MRF_DRSTM		0x0001

#define MRF_SYNBREG		0xCE00
#define MRF_SYNCB_MASK	0x00FF

#define MRF_DRSREG		0xC800
#define MRF_DRPE		0x0080
#define MRF_DRPV_MASK	0x007F

#define MRF_PMCREG		0x8200
#define MRF_RXCEN		0x0080
#define MRF_BBCEN		0x0040
#define MRF_TXCEN		0x0020
#define MRF_SYNEN		0x0010
#define MRF_OSCEN		0x0008
#define MRF_LBDEN		0x0004
#define	MRF_WUTEN		0x0002
#define MRF_CLKODIS		0x0001

#define MRF_WTSREG		0xE000
#define MRF_WTEV_MASK	0x1F00
#define MRF_WTMV_MASK	0x00FF

#define MRF_DCSREG		0xC800
#define MRF_DCMV_MASK	0x00FE
#define MRF_DCMEN		0x0001

#define MRF_BCSREG		0xC000
#define MRF_COFSB_10	0x00F0
#define MRF_COFSB_5		0x00C0
#define MRF_COFSB_333	0x00A0
#define MRF_COFSB_25	0x0080
#define MRF_COFSB_2		0x0060
#define MRF_COFSB_166	0x0040
#define MRF_COFSB_15	0x0020
#define MRF_COFSB_1		0x0000
#define MRF_LBDVB_MASK	0x0008

#define MRF_PLLCREG		0xCC12
#define MRF_CBTC_5		0x0060
#define MRF_CBTC_3		0x0040
#define MRF_CBTC_2p		0x0020
#define MRF_CBTC_2m		0x0000
#define MRF_PDDS		0x0008
#define MRF_PLLDD		0x0004
#define MRF_PLLBWB		0x0001

#endif /* MRF49XA_REGISTRE_H_ */