/**
  * \file serial.c
  * \brief Communication par le port serie de l'ATMega
  * \author Nicolas Husse
  * \version 0.1
  * \date 05 novembre 2013
  */

#include "serial.h"

/**
  * \fn serial_init
  * \brief Initialisation de la communication serie.
  */
void serial_init(void)
{
	UBRR0H = BAUD_PRESCALE >> 8;
	UBRR0L = BAUD_PRESCALE;

	UCSR0C = _BV(UCSZ01) | _BV(UCSZ00) | _BV(UMSEL01); /* 8-bit data */
	UCSR0B = _BV(RXCIE0) | _BV(RXEN0) | _BV(TXEN0);   /* Enable RX and TX */
	
}

/**
  * \fn serial_send
  * \brief Envoie d'un octet sur le port serie.
  * \param[in] byteToSend : Octet  envoyer sur le port serie
  */
void serial_send(char byteToSend)
{
	while ((UCSR0A & (1 << UDRE0)) == 0) {};
	UDR0 = byteToSend;
}

/**
  * \fn serial_write
  * \brief Envoie d'une chaine de caractre sur le port serie.
  * \param[in] pstr : pointeur vers une chaine de caractre
  */
void serial_write(char * pstr)
{
	while (*pstr)
		serial_send(*(pstr++));
}

/** 
  * \fn serial_received
  * \brief Lit un octet provenant du port serie.
  * \return Retourne l'octet reu
  */
char serial_received(void)
{
	while ((UCSR0A & (1 << RXC0)) == 0) {};
	return UDR0;
}


