/**
  * \file serial.h
  * \brief Communication par le port serie de l'ATMega
  * \author Nicolas Husse
  * \version 0.1
  * \date 07 novembre 2013
  */

#ifndef SERIAL_H_
#define SERIAL_H_

#include "config.h"

#define USART_BAUDRATE 9600
#define BAUD_PRESCALE ((( F_CPU / ( USART_BAUDRATE * 16UL ))) - 1)

/**
  * \fn serial_init
  * \brief Initialisation de la communication serie.
  */
void serial_init(void);

/**
  * \fn serial_send
  * \brief Envoie d'un octet sur le port serie.
  * \param[in] byteToSend : Octet  envoyer sur le port serie
  */
void serial_send(char byteToSend);

/**
  * \fn serial_write
  * \brief Envoie d'une chaine de caractre sur le port serie.
  * \param[in] pstr : pointeur vers une chaine de caractre
  */
void serial_write(char * pstr);

/** 
  * \fn serial_received
  * \brief Lit un octet provenant du port serie.
  * \return Retourne l'octet reu
  */
char serial_received(void);



#endif /* SERIAL_H_ */