/**
  * \file spi.h
  * \brief Communication par le port spi de l'ATMega
  * \author Nicolas Husse
  * \version 0.1
  * \date 07 novembre 2013
  */

#ifndef SPI_H_
#define SPI_H_

#include "config.h"

#define SPI_MISO_PORT	PORTB
#define SPI_MISO_PIN	PINB
#define SPI_MISO_DDR	DDRB
#define SPI_MISO_BIT	4

#define SPI_MOSI_PORT	PORTB
#define SPI_MOSI_PIN	PINB
#define SPI_MOSI_DDR	DDRB
#define SPI_MOSI_BIT	3

#define SPI_SCLK_PORT	PORTB
#define SPI_SCLK_PIN	PINB
#define SPI_SCLK_DDR	DDRB
#define SPI_SCLK_BIT	5

unsigned int spi_buffer;
bool spi_mutex;

/**
  * \fn spi_init
  * \brief Initialisation de la communication spi.
  */
void spi_init(void);

/**
 * \fn spi_chip_select
 * \param[in] port_select : Port  selectionner
 * \param[in] pin_select : Pin  selectionner
 */
void spi_chip_select(unsigned int port_select, char pin_select);

/**
 * \fn spi_chip_unselect
 * \param[in] port_select : Port  deselectionner
 * \param[in] pin_select : Pin  deselectionner
 */
void spi_chip_unselect(unsigned int port_select, char pin_select);

/**
  * \fn spi_send
  * \brief Envoie d'un octet sur le port spi.
  * \param[in] byteToSend : Octet  envoyer sur le port spi
  * \return Retourne la valeur reu sur le port spi
  */
unsigned char spi_send(unsigned char byteToSend);

/**
  * \fn spi_send_word
  * \brief Envoie d'un mot sur le port spi.
  * \param[in] wordToSend : Mot  envoyer sur le port spi
  * \return Retourne la valeur reu sur le port spi
  */
unsigned int spi_send_word(unsigned int wordToSend);

/** 
  * \fn spi_received
  * \brief Lit un octet provenant du port spi.
  * \return Retourne l'octet reu
  */
unsigned char spi_received(void);

/** 
  * \fn spi_received_word
  * \brief Lit un mot provenant du port spi.
  * \return Retourne le mot reu
  */
unsigned int spi_received_word(void);

#endif /* SPI_H_ */